@@ -409,7 +409,7 @@ class Morpheme:
         """
         Adds a gloss in string-form to this morpheme.
 
-        :param gloss:
+        :param gloss:serialize_new_user
         :return:
         """
         self.glosses.append(gloss)
@@ -437,7 +437,7 @@ class Morpheme:
         :return: Void
         """
         if not isinstance(glosses, six.string_types):
-            raise Exception("Erroneous input to add_concatenated_glosses: Expected string, got " + type(glosses))
+            raise Exception("Erroneous input to add_concatenated_glosses: Expected string, got " + str(type(glosses)))
 
         for gloss in glosses.split("."):
             self.add_gloss(gloss)
@@ -507,4 +507,5 @@ class GlobalTag:
         self.level = level
         self.description = description  # Currently unused, but exists to mirror the implementation in TC-Core.
 
+
 DEFAULT_TAGSET = GlobalTagSet(1, "DEFAULT")
